@charset "UTF-8";
/* CSS Document */

body, div, h1, h2, h3, h4, h5, h6, p, ul, ol, li, dl, dt, dd, img, form, fieldset, input, textarea, blockquote {
    margin: 0; padding: 0; border: 0;
    position: relative;
}

.hidden {
    visibility: hidden;
}

body {
    background: #161616;
    margin: 0;
    padding: 0;
    color: #000000;
}

div.container {
    width: 95%;
    max-width: 1260px;/* a max-width may be desirable to keep this layout from getting too wide on a large monitor. This keeps line length more readable. IE6 does not respect this declaration. */
    min-width: 780px;/* a min-width may be desirable to keep this layout from getting too narrow. This keeps line length more readable in the side columns. IE6 does not respect this declaration. */
    background: #161616;
    margin: 0 auto; /* the auto value on the sides, coupled with the width, centers the layout. It is not needed if you set the .container's width to 100%. */
}

div.header {
    background: #161616;
    margin: 30px 0px 10px 0px;
}
    div.header h1 {
        color: #1818D7;
        text-align: center;
        font-family: "Lucida Calligraphy";
        font-size: 26pt;
    }
    div.header p {
        display: inline;
    }

div.content {
    margin: 0 auto;
    padding: 10px 0;
    width: 100%;
    float: right;
    background: #161616;
    color: white;
}

div.footer {
    padding: 10px 0;
    background: #161616;
    color: white;
    position: relative;/* this gives IE6 hasLayout to properly clear */
    clear: both; /* this clear property forces the .container to understand where the columns end and contain them */
    text-align: center;
    }
