@charset "UTF-8";
/* CSS Document */

p.content-message {
	color: #CA8C1E;
}

div.content-navigation {
    margin: 10px 10px 10px 10px;
    padding: 5px 0px 0px 0px;
    color: #666666;
}
    span.content-navigation-current {
        font-weight: bold;
        font-family: Arial;
        font-size: 14px;
        color: white;
    }
    .content-navigation-options {
        float: right;
    }
div.content-info {
    margin: 10px 10px 10px 10px;
    padding: 0px;
    color: #666666;
}

div.content-header {
    margin: 10px 10px 10px 10px;
    padding: 5px 0px 0px 0px;
}
    .content-title {
		display: inline;
        margin-top: 0;
        color: #8CCA1E;
        font-size: 18px;
        font-weight: normal;
    }

a.navigation {
    font-weight: normal;
    font-family: Arial;
    font-size: 14px;
}

div.album-navigation-top {
    margin: 0px 10px 10px 10px;
    padding: 0px 0px 0px 0px;
    /* border-top: 1px solid #666666; */
    word-wrap: break-word;
    font-family: Arial;
    font-size: 14px;
    font-weight: bold;
    text-align: left;
}
div.album-navigation-bottom {
    margin: 10px 10px 10px 10px;
    padding: 5px 0px 0px 0px;
    border-top: 1px solid #666666;
    word-wrap: break-word;
    font-family: Arial;
    font-size: 14px;
    font-weight: bold;
    text-align: center;
}

div.content-description {
    margin: 10px 10px 10px 10px;
    padding: 5px 0px 0px 0px;
    border-top: 1px solid #666666;
    word-wrap: break-word;
    font-family: Arial;
    font-size: 14px;
}
div.content-description-bottom-line {
    margin: 10px 10px 0px 10px;
    padding: 5px 0px 0px 0px;
    border-top: 1px solid #666666;
}
div.content-footer {
    margin: 10px 10px 10px 10px;
    padding: 5px 0px 0px 0px;
    border-top: 1px solid #666666;
}

a:link { text-decoration:none; font-weight:normal; color:white; }
a:visited { text-decoration:none; font-weight:normal; color:white; }
a:hover { text-decoration:underline; font-weight:normal; color:white; }
a:active { text-decoration:underline; font-weight:normal; color:white; }
a:focus { text-decoration:none; font-weight:normal; color:white; }
a.navigation-first{
    font-weight: normal;
    font-size: 12px;
    margin-right: 10px;
}
a.navigation-prev{
    font-weight: normal;
    font-size: 12px;
    margin-right: 10px;
}
a.navigation-next{
    font-weight: normal;
    font-size: 12px;
    margin-left: 10px;
}
a.navigation-last{
    font-weight: normal;
    font-size: 12px;
    margin-left: 10px;
}

div.pictures {
    margin: 0px 0px 0px 0px;
    padding: 0px 10px 0px 10px;
    background: #161616;
    text-align: center;
}

    #list-order-dialog ul {
        margin: 0px 0px 0px 0px;
        padding: 0px 0px 0px 0px;
        position: relative;
        display: block;
    }
    #list-order-dialog li {
        margin: 10px;
        display: inline-block;
        list-style: none outside none;
        vertical-align: middle;
        text-align: center;
    }

    ul.picture-list {
        margin: 0px 0px 0px 0px;
        padding: 0px 0px 0px 0px;
        position: relative;
        display: block;
        background: #161616;
    }

    li.picture-item {
        margin: 0px 10px 0px 10px;
        padding: 40px 0px 40px 0px;
        display: inline-block;
        list-style: none outside none;
        vertical-align: middle;
        text-align: center;
    }

    div.picture-cell {
        margin: 0px 0px 0px 0px;
        padding: 0px;
        background: #666666;
    }

    div.picture-container {
        margin: 0px 0px 0px 0px;
        padding: 0px;
        vertical-align: middle;
        text-align: center;
    }
        a.picture-link {
            padding: 0px 0px 0px 0px;
            margin: 0px 0px 0px 0px;
            outline: medium none;
            text-align: center;
            vertical-align: middle;
        }
            img.image-box {
                padding: 0px 0px 0px 0px;
                margin: 0px 0px 0px 0px;
                background: no-repeat center center #161616;
                border: 1px solid #666666;
                padding: 1px;
            }
            img.image-box:hover {
                border: 1px solid #C2C2C2;
            }

    div.picture-info {
        margin: 0px 0px 0px 0px;
        padding: 0px 1px 0px 1px;
        border: 1px solid #666666;
        background: #666666;
    }
        div.picture-descr {
            color: white;
            margin: 0px 0px 0px 0px;
            padding: 20px 0px 5px 10px;
            font-family: Arial;
            font-size: 14px;
            text-align: left;
        }

div.albums {
    margin: 0px 0px 30px 0px;
    padding: 0px 10px 0px 10px;
    background: #161616;
    text-align: center;
}

    ul.album-list {
        margin: 0px 80px 0px 80px;
        padding: 20px 20px 20px 20px;
        position: relative;
        display: block;
        background: #2D2D2D;
        border: 1px solid #666666;
        border-radius: 30px;
        -moz-border-radius: 30px;
    }

    li.album-item {
        margin: 0px;
        padding: 40px 20px 40px 20px;
        display: inline-block;
        list-style: none outside none;
        vertical-align: middle;
        text-align: center;
    }

    div.album-cell {
        margin: 0px 0px 0px 0px;
        padding: 0px;
        background: #666666;
    }

    div.album-container {
        margin: 0px 0px 0px 0px;
        padding: 0px;
        vertical-align: middle;
        text-align: center;
    }
        a.album-link {
            padding: 0px 0px 0px 0px;
            margin: 0px 0px 0px 0px;
            outline: medium none;
            text-align: center;
            vertical-align: middle;
        }
            img.image-box {
                padding: 0px 0px 0px 0px;
                margin: 0px 0px 0px 0px;
                background: no-repeat center center #161616;
                border: 1px solid #666666;
                padding: 1px;
            }
            img.image-box:hover {
                border: 1px solid #C2C2C2;
            }

    div.children-order-edit {
    }
		div.children-order-edit p {
			text-align: center;
			display: inline;
		}

    div.preview-picture-edit {
        margin: 0px 0px 0px 0px;
        padding: 0px 1px 0px 1px;
        border: 1px solid #666666;
        background: #666666;
        font-family: Arial;
        font-size: 14px;
        text-align: left;
    }
        div.preview-picture-edit p {
            color: white;
            margin: 0px 0px 0px 0px;
            padding: 5px 0px 5px 10px;
            font-family: Arial;
            font-size: 14px;
            text-align: left;
    }
    div.album-info {
        margin: 0px 0px 0px 0px;
        padding: 0px 1px 0px 1px;
        border: 1px solid #666666;
        background: #666666;
    }
        div.album-descr {
            color: white;
            margin: 0px 0px 0px 0px;
            padding: 20px 0px 5px 10px;
            font-family: Arial;
            font-size: 14px;
            text-align: left;
        }


#resource-tree-lightbox {
	vertical-align: middle;
	margin: 0px;
	padding: 0px;
	color: white;
	background: #2D2D2D;
	border: 2px solid #666;
	border-radius: 15px;
	-moz-border-radius: 15px;
	overflow: visible;
}
	#resource-tree-lightbox .tree,
	#resource-tree-lightbox .attributes {
		padding: 0px;
		margin: 20px;
		overflow: scroll;
	}

#login-lightbox {
	vertical-align: middle;
	text-align: center;
	margin: 0px;
	padding: 20px;
	display: table;
	color: white;
	border: 2px solid #666;
	border-radius: 15px;
	-moz-border-radius: 15px;
}
#login-lightbox p {
	display: table-row;
}
#login-lightbox span,
#login-lightbox input {
	display: table-cell;
}

.simplemodal-container {
	padding: 0px;
	overflow: auto;
}
#picture-lightbox {
	vertical-align: middle;
	text-align: center;
	margin: 0px;
	padding: 0px;
	display: table;
	color: white;
}
	#picture-lightbox .control-bar a:link
		{ text-decoration:none; font-weight:normal; color:white; }
	#picture-lightbox .control-bar a:visited
		{ text-decoration:none; font-weight:normal; color:white; }
	#picture-lightbox .control-bar a:hover
		{ text-decoration:none; font-weight:bold; color:white; }
	#picture-lightbox .control-bar a:active
		{ text-decoration:none; font-weight:bold; color:white; }
	#picture-lightbox .control-bar a:focus
		{ text-decoration:none; font-weight:normal; color:white; }

	#picture-lightbox .navigate:link,
	#picture-lightbox .navigate a:link
		{ text-decoration:none; font-weight:normal; color:white; }
	#picture-lightbox .navigate:visited,
	#picture-lightbox .navigate a:visited
		{ text-decoration:none; font-weight:normal; color:white; }
	#picture-lightbox .navigate:hover,
	#picture-lightbox .navigate a:hover
		{ text-decoration:none; font-weight:bold; color:white; }
	#picture-lightbox .navigate:active,
	#picture-lightbox .navigate a:active
		{ text-decoration:none; font-weight:bold; color:white; }
	#picture-lightbox .navigate:focus,
	#picture-lightbox .navigate a:focus
		{ text-decoration:none; font-weight:normal; color:white; }

	#picture-lightbox div.control-box {
	}
		#picture-lightbox div.control-bar {
			margin: 5px 0px 5px 0px;
			padding: 5px 0px 5px 0px;
			font-weight: normal;
			color: #666666;
		}
			#picture-lightbox div.control-bar a {
				color: white;
			}
			#picture-lightbox div.control-bar a.pg-disabled {
				color: #666666;
			}
	#picture-lightbox div.content-box {
		vertical-align: middle;
		text-align: center;
	}
	#picture-lightbox div.content-box div {
		vertical-align: middle;
		color: grey;
		font-size: 30px;
	}
	#picture-lightbox div.picture img {
		background: #060606;
		padding: 10px;
		border: 2px solid #666;
		border-radius: 15px;
		-moz-border-radius: 15px;
	}

#picture-order-list-dialog,
#select-preview-picture-dialog {
	vertical-align: middle;
	text-align: center;
	margin: 10px;
	padding: 10px;
	border: 2px solid #666;
	border-radius: 15px;
	-moz-border-radius: 15px;
	background: #222;
}
	#picture-order-list-dialog div.control-bar,
	#select-preview-picture-dialog div.control-bar {
		margin: 10px;
		color: white;
		font-weight: bold;
	}
	#picture-order-list-dialog ul,
	#select-preview-picture-dialog ul {
		display: block;
		margin: 0px;
		padding: 0px;
	}
		#picture-order-list-dialog ul li,
		#select-preview-picture-dialog ul li {
			display: inline-block;
			margin: 5px;
			border: 1px solid #444;
			border-radius: 6px;
			-moz-border-radius:	6px;
			color: white;
			font-weight: normal;
			font-size: 12px;
			padding: 5px;
		}
			#select-preview-picture-dialog ul li.ui-selected {
				background: #aa0;
			}

.pg-editable {
	display: inline;
}

.pg-edit-container {
    font-size: 14px;
    color: white;
    font-weight: normal;
    font-family: Arial;
}
.pg-edit-action {
    display: block;
}
.pg-edit-status-field {
    font-weight: bold;
}
.pg-edit-text,
.pg-edit-multiline-text,
.pg-edit-date {
    color: white;
    background: black;
    border: 2px solid #0aa;
    border-radius: 6px;
	-moz-border-radius: 6px;
    /*font-size: 80%;*/
    padding: 2px;
}
.pg-edit-text {
    width: 80%;
}
.pg-edit-multiline-text {
    font-size: 100%;
}

.footer .copyright {
    font-size: 13px;
    color: #444;
}
